@@ -9,8 +9,7 @@ use std::{ffi::CStr, fmt, marker::PhantomData, os::raw};
 pub use run_handler::RunHandler;
 
 pub type Shaper = RefHandle<SkShaper>;
-unsafe impl Send for Shaper {}
-unsafe impl Sync for Shaper {}
+unsafe_send_sync!(Shaper);
 
 impl NativeDrop for SkShaper {
     fn drop(&mut self) {
@@ -457,7 +456,7 @@ impl<'a, T: RunHandler> AsRunHandler<'a> for T {
     where
         'b: 'a,
     {
-        let param = rust_run_handler::new_param(self);
+        let param = unsafe { rust_run_handler::new_param(self) };
         rust_run_handler::from_param(&param)
     }
 }
@@ -568,9 +567,9 @@ mod rust_run_handler {
         }
     }
 
-    pub fn new_param(run_handler: &mut dyn RunHandler) -> RustRunHandler_Param {
+    pub unsafe fn new_param(run_handler: &mut dyn RunHandler) -> RustRunHandler_Param {
         RustRunHandler_Param {
-            trait_: unsafe { mem::transmute(run_handler) },
+            trait_: mem::transmute(run_handler),
             beginLine: Some(begin_line),
             runInfo: Some(run_info),
             commitRunInfo: Some(commit_run_info),
